arsenal.maths.stats package
===========================

Submodules
----------

arsenal.maths.stats.corpus\_permutation\_test module
----------------------------------------------------

.. automodule:: arsenal.maths.stats.corpus_permutation_test
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.maths.stats.permutation\_test module
--------------------------------------------

.. automodule:: arsenal.maths.stats.permutation_test
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: arsenal.maths.stats
   :members:
   :undoc-members:
   :show-inheritance:
